/*
  Java gfx-test framework

   Copyright (C) 2010, 2011, 2012  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
*/

package org.gfxtest.harness;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Font;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStreamReader;



import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;
import javax.swing.WindowConstants;

public class SourceViewer
{
    /**
     * Default encoding used for all input/output operations.
     */
    private static final String DEFAULT_ENCODING = "UTF-8";

    protected JFrame frame = new JFrame(Configuration.getWindowTitle());
    private JTextArea textArea = new JTextArea();
    private JButton buttonClose = new JButton("Close");
    private Dialogs dialogs = new Dialogs(Configuration.getWindowTitle(), this.frame);

    public void showSource(String selectedTestSuite)
    {
        try
        {
            readSourceFile(selectedTestSuite);
            constructFrame();
            this.frame.setVisible(true);
        }
        catch (IOException e)
        {
            this.dialogs.showErrorMessage(e.getMessage());
        }
    }

    private void readSourceFile(String selectedTestSuite) throws IOException
    {
        File fin = new File(Configuration.getTestSourcesDirectory(), selectedTestSuite + ".java");
        if (!fin.exists())
        {
            throw new IOException("File " + fin.getCanonicalPath() + " not found");
        }
        BufferedReader reader = null;
        try
        {
            reader = new BufferedReader(new InputStreamReader(new FileInputStream(fin), DEFAULT_ENCODING));
            String line;
            while ((line = reader.readLine()) != null)
            {
                this.textArea.append(line);
                this.textArea.append("\n");
            }
        }
        finally
        {
            if (reader != null)
            {
                reader.close();
            }
        }
    }

    private void constructFrame() {
        this.textArea.setCaretColor(Color.red);
        this.textArea.setEditable(false);
        this.textArea.setFont(new Font("Monospaced", Font.PLAIN, 12));
        this.frame.setDefaultCloseOperation(WindowConstants.DISPOSE_ON_CLOSE);
        this.frame.setSize(640, 480);
        this.buttonClose.addActionListener(new ActionListener()
        {
            @Override
            public void actionPerformed(ActionEvent e) {
                SourceViewer.this.frame.dispose();
            }
        });
        this.frame.setLayout(new BorderLayout());
        this.frame.add(new JScrollPane(this.textArea), BorderLayout.CENTER);
        this.frame.add(this.buttonClose, BorderLayout.SOUTH);
    }

}
