/*
  Java gfx-test framework

   Copyright (C) 2010, 2011, 2012  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
*/

package org.gfxtest.reporter;

/**
 * Instances of this class contain results of one test run.
 *
 * @author Pavel Tisnovsky
 */
public class TestResult
{
    /**
     * Total test run.
     */
    private int totalTests;

    /**
     * Number of images which are the same after comparison.
     */
    private int sameImages;

    /**
     * Number of images which are different after comparison.
     */
    private int differentImages;

    /**
     * Empty constructor
     */
    public TestResult()
    {
        // empty as expected
    }

    /**
     * Constructor.
     * 
     * @param totalTests
     *            total test run
     * @param sameImages
     *            number of images which are the same after comparison
     * @param differentImages
     *            number of images which are different after comparison
     */
    public TestResult(int totalTests, int sameImages, int differentImages)
    {
        super();
        // set all attributes
        setTotalTests(totalTests);
        setSameImages(sameImages);
        setDifferentImages(differentImages);
    }

    /**
     * Getter for an attribute totalTests.
     * 
     * @return value of an attribute totalTests
     */
    public int getTotalTests()
    {
        return this.totalTests;
    }

    /**
     * Setter for an attribute totalTests.
     * 
     * @param totalTests
     *            new value of an attribute totalTests
     */
    public void setTotalTests(int totalTests)
    {
        this.totalTests = totalTests;
    }

    /**
     * Getter for an attribute sameImages.
     * 
     * @return value of an attribute sameImages
     */
    public int getSameImages()
    {
        return this.sameImages;
    }

    /**
     * Setter for an attribute sameImages.
     *
     * @param sameImages
     *            new value of an attribute sameImages
     */
    public void setSameImages(int sameImages)
    {
        this.sameImages = sameImages;
    }

    /**
     * Getter for an attribute differentImages.
     * 
     * @return value of an attribute differentImages
     */
    public int getDifferentImages()
    {
        return this.differentImages;
    }

    /**
     * Setter for an attribute differentImages.
     *
     * @param differentImages
     *            new value of an attribute differentImages
     */
    public void setDifferentImages(int differentImages)
    {
        this.differentImages = differentImages;
    }

    /**
     * Returns string containing test results.
     */
    @SuppressWarnings({ "boxing", "nls" })
    @Override
    public String toString()
    {
        return String.format("all: %d, same: %d, diff: %d", this.getTotalTests(), this.getSameImages(), this.getDifferentImages());
    }
}
